<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

/**
 * Description of attribute
 *
 * @author Igor Ratsun
 */
class Attribute
{

    protected $attrs = array();

    public function __construct($param = array())
    {
        $ci = & get_instance();
        $this->attrs = array(
            1 => $ci->lang->line('Text'),
            2 => $ci->lang->line('Select'),
            3 => $ci->lang->line('Multiselect'),
            4 => $ci->lang->line('Textarea'),
            5 => $ci->lang->line('Text editor'),
        );
    }

    public function fetchAll()
    {
        return $this->attrs;
    }

}
