<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

$config['product_photo_path'] = '/assets/uploads/multimedia/images/products/';
$config['product_photo_width'] = 2000;
$config['product_photo_height'] = 2000;
$config['product_icon_photo_path'] = '/assets/uploads/multimedia/images/icons/';

// Product group configuration for resmng
$config['product_group_page_template'] = 2;
$config['product_group_page_parent_id'] = 3;
$config['product_group_page_route'] = '';

// Product configuration for resmng
$config['product_page_template'] = 3;
$config['product_page_route'] = '';

$config['product_currency_callback'] = 'price_usd';
