<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

$config['upgrade_product'] = [
    [
        'version' => '0',
        'library' => 'product/migrations/product_upgrade_0',
    ],
    [
        'version' => '3.0.0',
        'library' => 'product/migrations/product_upgrade_3_0_0',
    ],
];
